@@ -1,3 +1,6 @@
+skip_on_cran()
+
+
 tmp = tempfile()
 status = topodb_download(county = "Sopot", outdir = tmp, unzip = FALSE) # 2.4 MB
 
@@ -7,14 +10,8 @@ if (!is.null(status)) {
 }
 
 file_path = list.files(tmp, full.names = TRUE)
-file_size = file.info(file_path)$size / 2^20
 file_ext = substr(file_path, nchar(file_path) - 2, nchar(file_path))
 
-
-test_that("check file size", {
-  expect_true(file_size > 1)
-})
-
 test_that("check file ext", {
   expect_true(file_ext == "zip")
 })
@@ -29,14 +26,8 @@ if (!is.null(status)) {
 }
 
 file_path = list.files(tmp, full.names = TRUE, recursive = TRUE)
-file_number = length(file_path)
 file_ext = substr(file_path, nchar(file_path) - 2, nchar(file_path))
 
-
-test_that("check number of files", {
-  expect_true(file_number == 89L)
-})
-
 test_that("check if zip is removed", {
   expect_true(!"zip" %in% file_ext)
 })
